unit EanRead;

interface

uses
  Windows, Messages, SysUtils, Classes, Controls,Dialogs;

resourcestring rsErrorOpeningComPort='Error opening com port.';
type

  TComDtrControl = (dtrEnable, dtrDisable, dtrHandshake);
  TComRtsControl = (rtsDisable, rtsEnable, rtsHandshake,  rtsToggle);
  TComParity    = (parityNone, parityEven, parityOdd, parityMark);
  TComPort      = (com1, com2, com3, com4, com5, com6, com7, com8);
  TComStopBits  = (stop1, stop15, stop2);
  TComOpenMode  = (omClosed, omOpenRead, omOpenWrite, omOpenReadWrite);


  EComError_ErrorOpening     = class(Exception);
  EComError_ThreadNotCreated = class(Exception);

  // thread for  reading from port
  TpsReadThread = class(TThread)
  private
  public
        FComHandle : THandle;
        procedure Execute;
  end;


  TpsWriteThread = class(TThread)
  end;

  // basic com port component
  TpsComPort = class(TComponent)
  private
     FComHandle   : THandle;
     FActive      : TComOpenMode;
     FComPort     : TComPort;
     FBaudRate    : Cardinal;
     FBinaryMode  : Boolean;
     FParity      : TComParity;
     FCtsControl  : Boolean;
     FDsrControl  : Boolean;
     FDtrControl  : TComDtrControl;
     FDsrSensitivity : Boolean;
     FContinueOnXoff : Boolean;
     FOutX, FInX     : Boolean;
     FOnX,FOffX      : Boolean;
     FErrorCharEnable : Boolean;
     FErrorChar      : Char;
     FNullEnable     : Boolean;
     FrtsControl     : TComRtsControl;
     FAbortOnError   : Boolean;
     FxOn, FxOff     : Boolean;
     FByteSize       : Word;
     FStopBits       : TComStopBits;
     FXonChar, FXoffChar, FEofChar, FevtChar : Char;
     FReadThread     : TpsReadThread;
     FWriteThread    : TpsWriteThread;
    procedure SetActive(const Value: TComOpenMode);
    procedure ReadThreadOpen;
    procedure WriteThreadOpen;
    procedure ReadThreadClose;
    procedure WriteThreadClose;
    procedure CloseAll;
  protected
  public
     function    ComPortName : String ;
     constructor Create(AOwner:TComponent); override;
     destructor  Destroy; override;
     procedure   Loaded;  override;
     procedure   OpenPort;
     procedure   ClosePort;
  published
     property Active    :TComOpenMode Read FActive      Write SetActive;
     property Port      :TComPort    Read FComPort      Write FComPort;
     property BaudRate  :Cardinal    Read FBaudRate     Write FBaudRate;
     property BinaryMode:Boolean     Read FBinaryMode   Write FBinaryMode;
     property Parity    :TComParity  Read FParity       Write FParity;
     property CtsControl:Boolean     Read FCtsControl   Write FCtsControl;
     property DsrControl:Boolean     Read FDsrControl   Write FDsrControl;
     property DtrControl:TComDtrControl Read FDtrControl   Write FDtrControl;
     property DsrSensitivity:Boolean Read FDsrSensitivity Write FDsrSensitivity;
     property ContinueOnXoff:Boolean Read FContinueOnXoff Write FContinueOnXoff;
     property OnX:Boolean            Read FOnX            Write FOnX;
     property OffX:Boolean           Read FOffX           Write FOffX;
     property ErrorCharEnable:Boolean Read FErrorCharEnable Write FErrorCharEnable;
     property ErrorChar:Char          Read FErrorChar       Write FErrorChar;
     property NullEnable:Boolean      Read FNullEnable      Write FNullEnable;
     property RtsControl:TComRtsControl Read FRtsControl Write FRtsControl;
     property AbortOnError:Boolean      Read FAbortOnError Write FAbortOnError;
     property XON :Boolean              Read FxOn          Write FxOn;
     property XOFF:Boolean              Read FxOff         Write FxOff;
     property ByteSize:Word             Read FByteSize     Write FByteSize;
     property StopBits:TComStopBits     Read FStopBits     Write FStopBits;
     property XonChar:Char              Read FXonChar      Write FXonChar;
     property XoffChar:Char             Read FXoffChar     Write FXoffChar;
     property EofChar:Char              Read FEofChar      Write FEofChar;
     property EvtChar:Char              Read FEvtChar      Write FEvtChar;

  end;

procedure Register;

implementation


{const
        com_mask_binary                 =
        com_mask_parity                 =
        com_mask_OutxCtsFlow            =
        com_mask_OutxDsrFlow            =
        com_mask_DtrControl             =
        com_mask_DsrSensitivity         =
        com_mask_TXContinueOnXoff       =
        com_mask_OutX                   =
        com_mask_InX                    =
        com_mask_ErrorChar              =
        com_mask_Null                   =
        com_mask_RtsControl             =
        com_mask_AbortOnError           =
        }


procedure Register;
begin
  RegisterComponents('EAN components', [TpsComPort]);
end;

{ TpsComPort }


{ TpsComPort }

function TpsComPort.ComPortName: String;
begin
        Result := 'Com'+IntToStr(Integer(FComPort)+1);
end;

constructor TpsComPort.Create(AOwner: TComponent);
begin
        inherited Create(AOwner);

        FBaudRate  := 9600;
        FByteSize  := 8;
        FComHandle := 0;
        FComPort   := com2;

        FReadThread     := nil;
        FWriteThread    := nil;

end;

destructor TpsComPort.Destroy;
begin
        ClosePort;
        inherited Destroy;
end;

procedure TpsComPort.Loaded;
begin
        inherited Loaded;
        OpenPort;
end;

procedure TpsComPort.OpenPort;
var m:integer;
begin
        if FComHandle<>0 then ClosePort;

        if FActive<>omClosed then begin
                m:=0;
                if FActive in [omOpenRead,  omOpenReadWrite] then Inc(m,GENERIC_READ);
                if FActive in [omOpenWrite, omOpenReadWrite] then Inc(m,GENERIC_WRITE);

                FComHandle:=CreateFile(PChar(ComPortName),
                                       m,  // read-write mode
                                       0,  // no sharing of com port
                                       nil,   // no security attributes
                                       OPEN_EXISTING,
                                       FILE_ATTRIBUTE_NORMAL + FILE_FLAG_OVERLAPPED,
                                       0);

                if FComHandle=INVALID_HANDLE_VALUE then begin
                        CloseAll;
                        raise EComError_ErrorOpening.Create(rsErrorOpeningComPort);
                end;

                if FActive in [omOpenRead,  omOpenReadWrite] then ReadThreadOpen;
                if FActive in [omOpenWrite, omOpenReadWrite] then WriteThreadOpen;



        end;
end;

procedure TpsComPort.ClosePort;
begin
        ReadThreadClose;
        WriteThreadClose;
        if FComHandle<>0 then CloseHandle(FComHandle);
        FComHandle := 0;
end;


procedure TpsComPort.SetActive(const Value: TComOpenMode);
begin
    if FActive<>Value then begin
        if (csLoading in ComponentState) or (csReading in ComponentState) then
                FActive := Value
        else begin
                ClosePort;
                FActive := Value;
                OpenPort;
        end;
    end;
end;


// dcb

// CreateEvent

procedure TpsComPort.ReadThreadClose;
begin
        {}
end;

procedure TpsComPort.WriteThreadClose;
begin
        {}
end;

procedure TpsComPort.ReadThreadOpen;
begin
        try
             FReadThread := TpsReadThread.Create(True);
        except
             FReadThread := nil;
             raise EComError_ThreadNotCreated.Create('Cannot create thread.');
        end;

        // FReadThread.
        FReadThread.Priority   := tpHighest;
        FReadThread.FComHandle := FComHandle;
        FReadThread.Resume;
end;

procedure TpsComPort.WriteThreadOpen;
begin

end;

procedure TpsComPort.CloseAll;
begin
        ReadThreadClose;
        WriteThreadClose;
        if FComHandle<>0 then CloseHandle(FComHandle);
        FComHandle   := 0;
        FActive      := omClosed;
end;

{ TpsReadThread }

procedure TpsReadThread.Execute;
var WaitFor_Handles : array [0..0] of THandle;
begin
        SetCommMask(FComHandle,  
        while not Terminated do begin

        end;

end;


// SetCommMask

end.
